@@ -64,6 +64,17 @@ class MultiAgentTrajectoryExporter:
         with open(plan_file_path, "rt") as plan_file:
             return plan_file.readlines()
 
+    def _create_initial_state(self, problem: Problem) -> State:
+        """Create the initial state of the problem.
+
+        :param problem: the problem object.
+        :return: the initial state of the problem.
+        """
+        initial_state_predicates = problem.initial_state_predicates
+        initial_state_numeric_fluents = problem.initial_state_fluents
+        previous_state = State(predicates=initial_state_predicates, fluents=initial_state_numeric_fluents, is_init=True)
+        return previous_state
+
     def create_multi_agent_triplet(self, previous_state: State, action_call: str) -> MultiAgentTrajectoryTriplet:
         """Create a single trajectory triplet by applying the joint action on the input state and combining the effects.
 
@@ -100,9 +111,7 @@ class MultiAgentTrajectoryExporter:
         """
         self.logger.info("Parsing the plan to extract the grounded operators.")
         plan_actions = action_sequence if action_sequence is not None else self._read_plan(plan_path)
-        initial_state_predicates = problem.initial_state_predicates
-        initial_state_numeric_fluents = problem.initial_state_fluents
-        previous_state = State(predicates=initial_state_predicates, fluents=initial_state_numeric_fluents, is_init=True)
+        previous_state = self._create_initial_state(problem)
         triplets = []
         self.logger.debug("Starting to create the trajectory triplets.")
         for grounded_action_call in plan_actions:
