@@ -80,3 +80,17 @@ def test_convert_plan_produces_readable_plan(woodworking_plan_converter: PlanCon
     print()
     for joint_action in joint_actions:
         print(joint_action)
+
+
+def test_convert_plan_when_removing_concurrency_constraint_creates_shorter_plan_than_if_we_do_not(
+        woodworking_plan_converter: PlanConverter):
+    short_joint_actions = woodworking_plan_converter.convert_plan(WOODWORKING_UNPARSED_PLAN_PATH,
+                                                                  agent_names=WOODWORKING_AGENT_NAMES,
+                                                                  should_validate_concurrency_constraint=False)
+    longer_joint_actions = woodworking_plan_converter.convert_plan(WOODWORKING_UNPARSED_PLAN_PATH,
+                                                                   agent_names=WOODWORKING_AGENT_NAMES)
+    assert len(short_joint_actions) < len(longer_joint_actions)
+
+    print()
+    for joint_action in short_joint_actions:
+        print(joint_action)
